@@ -39,7 +39,7 @@
       paste0(sample(c(1:9, LETTERS, letters), 20, replace = TRUE), collapse = ''),
     googleAuthR.tryAttempts = 5,
     googleAuthR.HttrRetryTimes = 3,
-    googleAuthR.HttrRetryTerminateOn = c(400,401,402,403,404,405,406,407,408,
+    googleAuthR.HttrRetryTerminateOn = c(400,401,402,403,404,405,406,407,
                                          409,410,411,412,413,414,415,416,417,
                                          418,421,422,423,424,426,428,
                                          431,451),
